@@ -14,7 +14,6 @@
 """
 
 import codecs
-import inspect
 import locale
 import logging
 import logging.handlers
@@ -384,7 +383,7 @@ class App(object):
             return 2
         cmd_factory, cmd_name, sub_argv = subcommand
         kwargs = {}
-        if 'cmd_name' in inspect.getargspec(cmd_factory.__init__).args:
+        if 'cmd_name' in utils.getargspec(cmd_factory.__init__).args:
             kwargs['cmd_name'] = cmd_name
         cmd = cmd_factory(self, self.options, **kwargs)
         err = None
